@@ -14,7 +14,7 @@ Usage::
     client: STSClient = boto3.client("sts")
     session_client: STSClient = session.client("sts")
 """
-from mypy_boto3_sts.client import STSClient as Client, STSClient
+from mypy_boto3_sts.client import STSClient, STSClient as Client
 
 
 __all__ = ("Client", "STSClient")
